/**
 * tlssep_status_t:
 * @TLSSEP_STATUS_OK: No error
 * @TLSSEP_STATUS_AGAIN: Try again
 * @TLSSEP_STATUS_ERROR: Generic error
 * @TLSSEP_STATUS_ERROR_TLS: Generic TLS error
 * @TLSSEP_STATUS_ERROR_RPC_FAILURE: RPC failure
 * @TLSSEP_STATUS_ERROR_ALLOCATION_FAILED: Error allocating memory
 * @TLSSEP_STATUS_ERROR_POLL_FAILED: Error polling decorator
 * @TLSSEP_STATUS_ERROR_SOCKET_FAILED: Error setting up a socket
 * @TLSSEP_STATUS_ERROR_SHM_FAILED: Error setting up shared memory
 * @TLSSEP_STATUS_ERROR_NOTIFICATION_FD_FAILED: Error setting up notification file descriptor
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_EXIT: Bad exit code from decorator
 * @TLSSEP_STATUS_ERROR_DECORATOR_FORK: Fork decorator error
 * @TLSSEP_STATUS_ERROR_DECORATOR_MISSING: Decorator missing
 * @TLSSEP_STATUS_ERROR_DECORATOR_NOT_A_FILE: Decorator not a regular file
 * @TLSSEP_STATUS_ERROR_DECORATOR_WRONG_PERMS: Decorator bears incorrect permissions
 * @TLSSEP_STATUS_ERROR_DESCRIPTORS_EXHAUSTED: No more descriptors available
 * @TLSSEP_STATUS_ERROR_TRANSMITTING_FILE_DESCRIPTOR: Error transmitting file descriptor
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERT_PATH: Decorator bad certificate path
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_PRIVKEY_PATH: Decorator bad private key path
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_PRIVKEY: Decorator bad private key
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CA_PATH: Decorator bad CA path
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_VERIFICATION_ENGINE: Bad verification engine
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE: Bad certificate
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_MISSING_ISSUER: Bad certificate, missing issuer
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_MISSING_CRL: Bad certificate, unable to obtain CRL
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_DECRYPT_SIGNATURE: Bad certificate, decryption of certificate signature failed
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_DECRYPT_CRL_SIGNATURE: Bad certificate, decryption of CRL signature failed
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_DECODE_ISSUER_PUBLIC_KEY: Bad certificate, public key could not be read
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_SIGNATURE: Bad certificate, invalid signature
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_CRL_SIGNATURE: Bad certificate, invalid CRL signature
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_NOT_YET_VALID: Bad certificate, not yet valid
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_EXPIRED: Bad certificate, expired
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_CRL_NOT_YET_VALID: Bad certificate, CRL not yet valid
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_CRL_EXPIRED: Bad certificate, CRL expired
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_INVALID_NOT_BEFORE: Bad certificate, invalid not before field
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_INVALID_NOT_AFTER: Bad certificate, invalid not after field
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_INVALID_CRL_LAST_UPDATE: Bad certificate, invalid CRL last update field
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_INVALID_CRL_NEXT_UPDATE: Bad certificate, invalid CRL next update field
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_SELF_SIGNED: Bad certificate, self signed
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_SELF_SIGNED_CHAIN: Bad certificate, self signed certificate in chain
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_LEAF: Bad certificate, chain of one
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_CHAIN_TOO_LONG: Bad certificate, chain too long
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_REVOKED: Bad certificate, revoked
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_INVALID_CA: Bad certificate, invalid CA certificate
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_PATH: Bad certificate, path length exceeded
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_PURPOSE: Bad certificate, unsupported certificate purpose
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_UNTRUSTED: Bad certificate, root CA not trusted
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_REJECTED: Bad certificate, rejected
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_ISSUER_MISMATCH: Bad certificate, subject issuer mismatch
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_AKID_SKID_MISMATCH: Bad certificate, subject key identifier did not match the authority key identifier of the current certificate
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_AKID_ISSUER_SERIAL_MISMATCH: Bad certificate, issuer name and serial number did not match authority key identifier of the current certificate
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_SIGN_DISALLOWED: Bad certificate, issuer not permitted to sign certificates
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_INVALID_EXTENSION: Bad certificate, invalid extension
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_INVALID_POLICY_EXTENSION: Bad certificate, invalid policy extension
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_NO_EXPLICIT_POLICY: Bad certificate, no required policy present
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_DIFFERENT_CRL_SCOPE: Bad certificate, CRLs do not match scope of certificate
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_UNSUPPORTED_EXTENSION_FEATURE: Bad certificate, unsupported extension feature
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_PERMITTED_VIOLATION: Bad certificate, constraint violation in permitted subtrees
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_EXCLUDED_VIOLATION: Bad certificate, constraint violation in excluded subtrees
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_SUBTREE_MINMAX: Bad certificate, constraints extension included minimum or maximum field
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_UNSUPPORTED_CONSTRAINT_TYPE: Bad certificate, unsupported name constraint type encountered
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_UNSUPPORTED_CONSTRAINT_SYNTAX: Bad certificate, format of the name constraint unrecognized
 * @TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_CRL_PATH_VALIDATION: Bad certificate, CRL path validation error
 * @TLSSEP_STATUS_ERROR_DECORATOR_ERROR_SETTING_FD: Failed to set file descriptor
 * @TLSSEP_STATUS_ERROR_DECORATOR_MISSING_CERTIFICATE: Missing certificate
 * @TLSSEP_STATUS_ERROR_DECORATOR_MISSING_CERTIFICATE_CHAIN: Could not extract peer certificate chain
 * @TLSSEP_STATUS_ERROR_DECORATOR_CERTIFICATE_MISMATCH: Unexpected name in certificate
 * @TLSSEP_STATUS_ERROR_DECORATOR_CERTIFICATE_NAME_CONTAINS_NULL: Name in certificate contains 0x00
 * @TLSSEP_STATUS_ERROR_DECORATOR_SET_NONBLOCK: Unable to set file descriptor nonblocking
 * @TLSSEP_STATUS_ERROR_DECORATOR_CLOSE: Unable to close file descriptor
 * @TLSSEP_STATUS_ERROR_CLOSED: The TLS connection is closed
 * @TLSSEP_STATUS_ERROR_SYSCALL: A system call returned an error
 *
 * Enum values used to specify status conditions.
 */
typedef enum tlssep_status_t {
	TLSSEP_STATUS_OK,
	TLSSEP_STATUS_AGAIN,
	TLSSEP_STATUS_ERROR,
	TLSSEP_STATUS_ERROR_TLS,
	TLSSEP_STATUS_ERROR_RPC_FAILURE,
	TLSSEP_STATUS_ERROR_ALLOCATION_FAILED,
	TLSSEP_STATUS_ERROR_POLL_FAILED,
	TLSSEP_STATUS_ERROR_SOCKET_FAILED,
	TLSSEP_STATUS_ERROR_SHM_FAILED,
	TLSSEP_STATUS_ERROR_NOTIFICATION_FD_FAILED,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_EXIT,
	TLSSEP_STATUS_ERROR_DECORATOR_FORK,
	TLSSEP_STATUS_ERROR_DECORATOR_MISSING,
	TLSSEP_STATUS_ERROR_DECORATOR_NOT_A_FILE,
	TLSSEP_STATUS_ERROR_DECORATOR_WRONG_PERMS,
	TLSSEP_STATUS_ERROR_DESCRIPTORS_EXHAUSTED,
	TLSSEP_STATUS_ERROR_TRANSMITTING_FILE_DESCRIPTOR,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERT_PATH,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_PRIVKEY_PATH,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_PRIVKEY,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CA_PATH,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_VERIFICATION_ENGINE,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_MISSING_ISSUER,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_MISSING_CRL,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_DECRYPT_SIGNATURE,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_DECRYPT_CRL_SIGNATURE,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_DECODE_ISSUER_PUBLIC_KEY,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_SIGNATURE,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_CRL_SIGNATURE,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_NOT_YET_VALID,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_EXPIRED,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_CRL_NOT_YET_VALID,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_CRL_EXPIRED,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_INVALID_NOT_BEFORE,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_INVALID_NOT_AFTER,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_INVALID_CRL_LAST_UPDATE,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_INVALID_CRL_NEXT_UPDATE,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_SELF_SIGNED,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_SELF_SIGNED_CHAIN,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_LEAF,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_CHAIN_TOO_LONG,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_REVOKED,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_INVALID_CA,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_PATH,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_PURPOSE,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_UNTRUSTED,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_REJECTED,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_ISSUER_MISMATCH,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_AKID_SKID_MISMATCH,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_AKID_ISSUER_SERIAL_MISMATCH,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_SIGN_DISALLOWED,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_INVALID_EXTENSION,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_INVALID_POLICY_EXTENSION,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_NO_EXPLICIT_POLICY,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_DIFFERENT_CRL_SCOPE,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_UNSUPPORTED_EXTENSION_FEATURE,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_PERMITTED_VIOLATION,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_EXCLUDED_VIOLATION,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_SUBTREE_MINMAX,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_UNSUPPORTED_CONSTRAINT_TYPE,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_UNSUPPORTED_CONSTRAINT_SYNTAX,
	TLSSEP_STATUS_ERROR_DECORATOR_BAD_CERTIFICATE_CRL_PATH_VALIDATION,
	TLSSEP_STATUS_ERROR_DECORATOR_ERROR_SETTING_FD,
	TLSSEP_STATUS_ERROR_DECORATOR_MISSING_CERTIFICATE,
	TLSSEP_STATUS_ERROR_DECORATOR_MISSING_CERTIFICATE_CHAIN,
	TLSSEP_STATUS_ERROR_DECORATOR_CERTIFICATE_MISMATCH,
	TLSSEP_STATUS_ERROR_DECORATOR_CERTIFICATE_NAME_CONTAINS_NULL,
	TLSSEP_STATUS_ERROR_DECORATOR_SET_NONBLOCK,
	TLSSEP_STATUS_ERROR_DECORATOR_CLOSE,
	TLSSEP_STATUS_ERROR_CLOSED,
	TLSSEP_STATUS_ERROR_SYSCALL,
	/*< private >*/
 	TLSSEP_STATUS_LAST,
 } tlssep_status_t;
